﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace MonLog
{
    public partial class MainFrame : Form
    {

        //*************************************************************
        // WIN32関連
        //*************************************************************
        private struct POINTAPI
        {
            public int x;
            public int y;
        }

        [DllImport("user32.dll")]
        private extern static int GetCursorPos(ref POINTAPI pPoint);
        [DllImport("user32.dll")]
        private extern static int ScreenToClient(int hwnd, ref POINTAPI lpPoint);
         
        //*************************************************************
        // 定数定義
        //*************************************************************
        const string g_cstTITLE = "FAX情報表示"; //メッセージボックスのタイトル用

        const short TREE_SELECT_TYPE_LOG = 0;
        const short TREE_SELECT_TYPE_SEND_BEFORE = 1;
        const short TREE_SELECT_TYPE_SEND_AFTER = 2;
        const short TREE_SELECT_TYPE_RECEIVE = 3;

        const short s_cstMouseClickMode_Non = 100;
        const short s_cstMouseClickMode_RightClick = 300;

        //*************************************************************
        // 変数定義
        //*************************************************************
        private bool s_bPgmRun; // プログラム起動フラグ
        private short s_iMouseClickMode; // マウス状態
        private bool s_bListViewSort; // リストビューソートフラグ

        public MainFrame()
        {
            InitializeComponent();
        }

        //*************************************************************
        // プログラム起動
        //*************************************************************
        private void MainFrame_Load(object sender, EventArgs e)
        {
            string strMsg = "";

            //-------------------------------------------------------------
            // プログラム起動フラグリセット
            s_bPgmRun = false;

            //-------------------------------------------------------------
            // プログラムの２重起動不可
            if (System.Diagnostics.Process.GetProcessesByName(
                System.Diagnostics.Process.GetCurrentProcess().ProcessName).Length > 1)
            {
                strMsg = "すでに「";
                strMsg += g_cstTITLE;
                strMsg += "」は起動されています";

                MessageBox.Show(strMsg, g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }

            ///////////////////////////////////////////////////////////////
            //// STARFAX インストール確認

            if (axSFCSEnv1.CheckInstall() != clsSFCSEnvDef.SFCSENV_SUCCESS)
            {
                MessageBox.Show("STARFAX がインストールされていない、\nもしくは STARFAX 環境設定プログラム でフォルダ環境が設定されていません。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }

            ///////////////////////////////////////////////////////////////
            //// STARFAX サブフォルダ確認

            // 受信情報フォルダ
            if (axSFCSEnv1.CheckSubFolder(clsSFCSEnvDef.SFCSENV_SMODE_RECVINFO) != clsSFCSEnvDef.SFCSENV_SUCCESS) 
            {
                MessageBox.Show("受信情報フォルダが存在しません。\nSTARFAX を１度起動することにより、\n受信情報フォルダが作成されます。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }
            // 送信情報フォルダ
            if (axSFCSEnv1.CheckSubFolder(clsSFCSEnvDef.SFCSENV_SMODE_SENDINFO) != clsSFCSEnvDef.SFCSENV_SUCCESS)
            {
                MessageBox.Show("送信情報フォルダが存在しません。\nSTARFAX を１度起動することにより、\n送信情報フォルダが作成されます。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }
            // 未送信情報フォルダ
            if (axSFCSEnv1.CheckSubFolder(clsSFCSEnvDef.SFCSENV_SMODE_QUEINFO) != clsSFCSEnvDef.SFCSENV_SUCCESS)
            {
                MessageBox.Show("未送信情報フォルダが存在しません。\nSTARFAX を１度起動することにより、\n未送信情報フォルダが作成されます。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }

            // 受信情報削除命令フォルダ
            if (axSFCSEnv1.CheckSubFolder(clsSFCSEnvDef.SFCSENV_SMODE_RECVDELMIS) != clsSFCSEnvDef.SFCSENV_SUCCESS)
            {
                MessageBox.Show("受信情報削除命令フォルダが存在しません。\nSTARFAX を１度起動することにより、\n受信情報削除命令フォルダが作成されます。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }
            // 送信情報削除命令フォルダ
            if (axSFCSEnv1.CheckSubFolder(clsSFCSEnvDef.SFCSENV_SMODE_SENDDELMIS) != clsSFCSEnvDef.SFCSENV_SUCCESS)
            {
                MessageBox.Show("送信情報削除命令フォルダが存在しません。\nSTARFAX を１度起動することにより、\n送信情報削除命令フォルダが作成されます。",
                                g_cstTITLE ,MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }
            // 未送信情報削除命令フォルダ
            if (axSFCSEnv1.CheckSubFolder(clsSFCSEnvDef.SFCSENV_SMODE_QUEDELMIS) != clsSFCSEnvDef.SFCSENV_SUCCESS)
            {
                MessageBox.Show("未送信情報削除命令フォルダが存在しません。\nSTARFAX を１度起動することにより、\n未送信情報削除命令フォルダが作成されます。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                this.Close();
                return;
            }

            //////////////////////////////////////////////////////////////
            /// STARFAX サービス状態取得

            if (axSFCSEnv1.CheckServiceStatus() == clsSFCSEnvDef.SFCSENV_SERVICE_STOP)
            {
                MessageBox.Show("STARFAX が動作していないので、\n各種削除命令ファイルを作成しても、実際に削除動作は行われません。",
                                g_cstTITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
            }

            //////////////////////////////////////////////////////////////
            /// 各種ログの読み込み
            ///
            /// SFCSLogQueコントロール 《 未送信ログの読み込み 》
            ///   Function Load( Dlg As Integer ) as Long
            ///
            /// SFCSLogSendコントロール 《 送信ログの読み込み 》
            ///   Function Load( Dlg As Integer ) as Long
            ///
            /// SFCSLogRecvコントロール 《 受信ログの読み込み 》
            ///   Function Load( Dlg As Integer ) as Long
            ///

            axSFCSLogQue1.Load(clsSFCSLogDef.SFCSLOG_Dialog_TRUE);
            axSFCSLogSned1.Load(clsSFCSLogDef.SFCSLOG_Dialog_TRUE);
            axSFCSLogRecv1.Load(clsSFCSLogDef.SFCSLOG_Dialog_TRUE);

            //-------------------------------------------------------------
            // プログラム起動

            s_bPgmRun = true;

            this.TreeView.ExpandAll();


        } // MainFrame_Load


        //*************************************************************
        // プログラム終了
        //*************************************************************
        private void MainFrame_FormClosed(object sender, FormClosedEventArgs e)
        {

            //-------------------------------------------------------------
            // プログラム起動？

            if (s_bPgmRun == true)
            {
                //////////////////////////////////////////////////////////////
                /// 各種ログの読み込み 終了処理
                ///
                /// SFCSLogQueコントロール 《 未送信ログの読み込み 終了処理 》
                ///   Sub Release()
                ///
                /// SFCSLogSendコントロール 《 送信ログの読み込み 終了処理 》
                ///   Sub Release()
                ///
                /// SFCSLogRecvコントロール 《 受信ログの読み込み 終了処理 》
                ///   Sub Release()
                ///

                axSFCSLogQue1.Release();
                axSFCSLogSned1.Release();
                axSFCSLogRecv1.Release();

            }


        }

        //*************************************************************
        // ツリービュー: 項目選択
        //*************************************************************
        private void TreeView_AfterSelect(object sender, TreeViewEventArgs e)
        {
            short iVal = 0;
            //iVal = (short)this.TreeView.SelectedNode.Tag;
            if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_SEND_BEFORE.ToString()))
            {
                iVal = TREE_SELECT_TYPE_SEND_BEFORE;
            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_SEND_AFTER.ToString()))
            {
                iVal = TREE_SELECT_TYPE_SEND_AFTER;
            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_RECEIVE.ToString()))
            {
                iVal = TREE_SELECT_TYPE_RECEIVE;
            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
            {
                iVal = TREE_SELECT_TYPE_LOG;
            }

            SetListView(iVal);
        }

        //-------------------------------------------------------------
        // リストビュー設定 ( ログ )
        //-------------------------------------------------------------
        public void SetLogTypeLit()
        {
            this.ToolStripStatusLabel.Text = "";
            this.ListView.Columns.Clear();
            this.ListView.Columns.Add("名前", 200);

            int i;
            for (i = 0; i < this.TreeView.SelectedNode.Nodes.Count; i++ )
            {
                //????
                //this.ListView.Items.Add(this.TreeView.SelectedNode.Nodes.Item(i - 1).Text, 2);
                this.ListView.Items.Add(this.TreeView.SelectedNode.Nodes[i].Text, 2);
            }
        }

        //-------------------------------------------------------------
        // リストビュー設定 ( 未送信、送信、受信 )
        //-------------------------------------------------------------
        public void InitLogColHeader()
        {
            if (1 < this.ListView.Columns.Count)
            {
                return;
            }

            this.ListView.Columns.Clear();
            this.ListView.Columns.Add("通信結果", 8 * 8);       // 0
            this.ListView.Columns.Add("日付", 10 * 8);          // 1
            this.ListView.Columns.Add("時刻", 8 * 8);           // 2
            this.ListView.Columns.Add("回線番号", 8 * 8);       // 3
            this.ListView.Columns.Add("アカウント", 10 * 8);    // 4
            this.ListView.Columns.Add("相手先", 16 * 8);        // 5
            this.ListView.Columns.Add("FAX", 12 * 8);           // 6
            this.ListView.Columns.Add("ファイル名", 16 * 8);    // 7
            this.ListView.Columns.Add("ページ数", 8 * 8);       // 8
            this.ListView.Columns.Add("通信速度", 13 * 8);      // 9
            this.ListView.Columns.Add("通信時間", 8 * 8);       // 10
            this.ListView.Columns.Add("画品質", 8 * 8);         // 11
            this.ListView.Columns.Add("符号化", 6 * 8);         // 12
            this.ListView.Columns.Add("用紙サイズ", 10 * 8);    // 13
            this.ListView.Columns.Add("エラー訂正", 10 * 8);    // 14
            this.ListView.Columns.Add("回線指定", 8 * 8);       // 15
            this.ListView.Columns.Add("優先順位", 8 * 8);       // 16
            this.ListView.Columns.Add("リトライ回数", 12 * 8);  // 17
            this.ListView.Columns.Add("Ｆコード番号", 16 * 8);  // 18
            this.ListView.Columns.Add("パスワード", 16 * 8);    // 19
            this.ListView.Columns.Add("会社名", 16 * 8);        // 20
            this.ListView.Columns.Add("所属名", 16 * 8);        // 21
            this.ListView.Columns.Add("役職名", 16 * 8);        // 22
            this.ListView.Columns.Add("氏名", 16 * 8);          // 23
            this.ListView.Columns.Add("郵便番号", 8 * 8);       // 24
            this.ListView.Columns.Add("住所1", 16 * 8);         // 25
            this.ListView.Columns.Add("住所2", 16 * 8);         // 26
            this.ListView.Columns.Add("電話番号", 12 * 8);      // 27
            this.ListView.Columns.Add("FAX番号", 12 * 8);       // 28
            this.ListView.Columns.Add("敬称", 6 * 8);           // 29
            this.ListView.Columns.Add("ユーザ使用", 16 * 8);    // 30
            this.ListView.Columns.Add("記録位置", 16 * 8);      // 31
            this.ListView.Columns.Add("自局電話番号", 16 * 8);  // 32
            this.ListView.Columns.Add("ジョブID", 18 * 8);      // 33

        }


        //-------------------------------------------------------------
        // リストビュー表示
        //-------------------------------------------------------------
        public void SetListView(short LogType)
        {

            // ビューアメニュー、削除メニューをDisable
            mnuActionDisable();

            // 初期化
            this.ListView.Items.Clear();

            if (LogType == TREE_SELECT_TYPE_SEND_BEFORE)
            {

                // 未送信ログの表示
                ViewListViewQue();
            }
            else if (LogType == TREE_SELECT_TYPE_SEND_AFTER)
            {

                // 送信ログの表示
                ViewListViewSend();
            }
            else if (LogType == TREE_SELECT_TYPE_RECEIVE)
            {

                // 受信ログの表示
                ViewListViewRecv();
            }
            else
            {
                // ログが選択されたとき
                SetLogTypeLit();
            }


        }

        //-------------------------------------------------------------
        // 未送信ログの表示
        //-------------------------------------------------------------
        public void ViewListViewQue()
        {
            int lComStatus;
            int iImage;
            int i;
            string strTemp;

            InitLogColHeader();

            this.ListView.UseWaitCursor = true;

            //-------------------------------------------------------------
            // ステータスバー表示

            strTemp = "ログ件数:";
            strTemp += axSFCSLogQue1.GetRecCount().ToString();
            this.ToolStripStatusLabel.Text = strTemp;

            //////////////////////////////////////////////////////////////
            /// 未送信ログのリスト表示
            ///
            /// SFCSLogQueコントロール 《 未送信ログのレコード数 取得 》
            ///   Function GetRecCount() as Long
            ///

            string strWork;

            strWork = new string('\0', 1025);

            for (i = 0; i < axSFCSLogQue1.GetRecCount(); i++ )
            {
                string[] LstItems = { "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "" };


                //////////////////////////////////////////////////////////////
                /// 各項目の取得と表示
                ///
                /// SFCSLogQueコントロール 《 未送信ログのレコード項目 文字列取得 》
                ///   Function GetRecItemString( Rec As Long, Item As Integer,
                ///                              Get As String ) as Long
                ///

                // 通信結果
                iImage = 5;
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Return, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {

                    //////////////////////////////////////////////////////////////
                    /// 通信状態取得
                    ///
                    /// SFCSLogQueコントロール 《 未送信ログのレコード 通信状態取得 》
                    ///   Function GetRecComStatus( Rec As Long,
                    ///                             GetStatus As Long ) as Long
                    ///

                    // 通信状態
                    lComStatus = 0;
                    if (axSFCSLogQue1.GetRecComStatus(i, ref lComStatus) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                    {
                        if (lComStatus == 1)
                        {
                            iImage = 6;
                            LstItems.SetValue(strWork, 0);
                        }
                    }
                    if (lComStatus != 1)
                    {
                        if (strWork == "0")
                        {
                            iImage = 5;
                            LstItems.SetValue("0", 0);
                        }
                        else
                        {
                            iImage = 4;
                            LstItems.SetValue(strWork, 0);
                        }
                    }
                }

                // 日付/時刻
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Date, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 1);
                }

                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Time, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 2);
                }

                // 回線番号
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Line, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 3);
                }

                // アカウント
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Acount, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 4);
                }

                // 相手先
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_SendName, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 5);
                }

                // FAX
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FaxNumber, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 6);
                }

                // ファイル名
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FileName, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 7);
                }

                // ページ数
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Page, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 8);
                }

                // 通信速度
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermSpeed, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "2":
                            strWork = "2400bps";
                            break;
                        case "4":
                            strWork = "4800bps";
                            break;
                        case "7":
                            strWork = "7200bps(V.29)";
                            break;
                        case "9":
                            strWork = "9600bps(V.29)";
                            break;
                        case "A":
                            strWork = "7200bps(V.17)";
                            break;
                        case "B":
                            strWork = "9600bps(V.17)";
                            break;
                        case "C":
                            strWork = "12000bps";
                            break;
                        case "E":
                            strWork = "14400bps";
                            break;
                        case "G":
                            strWork = "16800bps";
                            break;
                        case "H":
                            strWork = "19200bps";
                            break;
                        case "I":
                            strWork = "21600bps";
                            break;
                        case "J":
                            strWork = "24000bps";
                            break;
                        case "K":
                            strWork = "26400bps";
                            break;
                        case "L":
                            strWork = "28800bps";
                            break;
                        case "M":
                            strWork = "31200bps";
                            break;
                        case "N":
                            strWork = "33600bps";
                            break;
                        default:
                            strWork = ""; 
                            break;
                    }
                    LstItems.SetValue(strWork, 9);
                }

                // 通信時間
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TotalTime, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 10);
                }

                // 画品質
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermReso, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "ノーマル";
                            break;
                        case "F":
                            strWork = "ファイン";
                            break;
                        case "S":
                            strWork = "スーパーファイン";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 11);
                }

                // 符号化
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermComp, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "M":
                            strWork = "MMR";
                            break;
                        case "R":
                            strWork = "MR";
                            break;
                        case "H":
                            strWork = "MH";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 12);
                }

                // 用紙サイズ
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermSize, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "A":
                            strWork = "A4";
                            break;
                        case "B":
                            strWork = "B4";
                            break;
                        case "3":
                            strWork = "A3";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 13);
                }

                // エラー訂正
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermECM, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "D":
                            strWork = "なし";
                            break;
                        case "E":
                            strWork = "ECM";
                            break;
                        case "S":
                            strWork = "ECM";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 14);
                }

                // 回線指定
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEMEX_LineDes, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "なし";
                            break;
                        case "0":
                            strWork = "回線１";
                            break;
                        case "1":
                            strWork = "回線２";
                            break;
                        case "2":
                            strWork = "回線３";
                            break;
                        case "3":
                            strWork = "回線４";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 15);
                }

                // 優先順位
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEMEX_Priority, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "";
                            break;
                        default:
                            break;
                    }
                    LstItems.SetValue(strWork, 16);
                }

                // リトライ回数
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Retry, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 17);
                }

                // Ｆコード番号
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FCode, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 18);
                }

                // パスワード
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Password, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 19);
                }

                // 会社名
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Company, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 20);
                }

                // 所属名
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Division, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 21);
                }

                // 役職名
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Position, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 22);
                }

                // 氏名
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Name, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 23);
                }

                // 郵便番号
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_ZipCode, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 24);
                }

                // 住所1
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Address1, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 25);
                }

                // 住所2
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Address2, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 26);
                }

                // 電話番号
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Telephone, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 27);
                }

                // FAX番号
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Fax, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 28);
                }

                // 敬称
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Title, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 29);
                }

                // ユーザ使用
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FreeArea, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 30);
                }

                // 記録位置
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_UserInfo, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 31);
                }

                // 自局電話番号
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_UserID, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 32);
                }

                // ジョブID
                if (axSFCSLogQue1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_JobID, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 33);
                }

                ListViewItem ListItem = new ListViewItem(LstItems, -1);

                ListItem.ImageIndex = iImage;

                this.ListView.Items.Add(ListItem);

            } // for (i = 0; i < axSFCSLogQue1.GetRecCount(); i++ )

            this.ListView.UseWaitCursor = false;

        } // ViewListViewQue()

        //-------------------------------------------------------------
        // 送信ログの表示
        //-------------------------------------------------------------
        public void ViewListViewSend()
        {
            int iImage;
            int i;
            string strTmp;

            InitLogColHeader();

            this.ListView.UseWaitCursor = true;

            //-------------------------------------------------------------
            // ステータスバー表示

            strTmp = "ログ件数:";
            strTmp += axSFCSLogSned1.GetRecCount().ToString();
            this.ToolStripStatusLabel.Text = strTmp;

            //////////////////////////////////////////////////////////////
            /// 送信ログのリスト表示
            ///
            /// SFCSLogSendコントロール 《 送信ログのレコード数 取得 》
            ///   Function GetRecCount() as Long
            ///

            string strWork;

            strWork = new string('\0', 1025);

            for (i = 0; i < axSFCSLogSned1.GetRecCount(); i++ )
            {

                string[] LstItems = {"", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", ""};

                //////////////////////////////////////////////////////////////
                /// 各項目の取得と表示
                ///
                /// SFCSLogQueコントロール 《 未送信ログのレコード項目 文字列取得 》
                ///   Function GetRecItemString( Rec As Long, Item As Integer,
                ///                              Get As String ) as Long
                ///

                // 通信結果
                iImage = 3;
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Return, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {

                    //////////////////////////////////////////////////////////////
                    /// 通信状態取得
                    ///
                    /// SFCSLogQueコントロール 《 未送信ログのレコード 通信状態取得 》
                    ///   Function GetRecComStatus( Rec As Long,
                    ///                             GetStatus As Long ) as Long
                    ///

                    // 通信状態
                    if (strWork == "0")
                    {
                        iImage = 3;
                        LstItems.SetValue("0", 0);
                    }
                    else
                    {
                        iImage = 4;
                        LstItems.SetValue(strWork, 0);
                    }
                }

                // 日付/時刻
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Date, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 1);
                }
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Time, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 2);
                }

                // 回線番号
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Line, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 3);
                }

                // アカウント
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Acount, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 4);
                }

                // 相手先
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_SendName, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 5);
                }

                // FAX
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FaxNumber, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 6);
                }

                // ファイル名
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FileName, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 7);
                }

                // ページ数
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Page, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 8);
                }

                // 通信速度
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermSpeed, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "2":
                            strWork = "2400bps";
                            break;
                        case "4":
                            strWork = "4800bps";
                            break;
                        case "7":
                            strWork = "7200bps(V.29)";
                            break;
                        case "9":
                            strWork = "9600bps(V.29)";
                            break;
                        case "A":
                            strWork = "7200bps(V.17)";
                            break;
                        case "B":
                            strWork = "9600bps(V.17)";
                            break;
                        case "C":
                            strWork = "12000bps";
                            break;
                        case "E":
                            strWork = "14400bps";
                            break;
                        case "G":
                            strWork = "16800bps";
                            break;
                        case "H":
                            strWork = "19200bps";
                            break;
                        case "I":
                            strWork = "21600bps";
                            break;
                        case "J":
                            strWork = "24000bps";
                            break;
                        case "K":
                            strWork = "26400bps";
                            break;
                        case "L":
                            strWork = "28800bps";
                            break;
                        case "M":
                            strWork = "31200bps";
                            break;
                        case "N":
                            strWork = "33600bps";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 9);
                }

                // 通信時間
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TotalTime, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 10);
                }

                // 画品質
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermReso, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "ノーマル";
                            break;
                        case "F":
                            strWork = "ファイン";
                            break;
                        case "S":
                            strWork = "スーパーファイン";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 11);
                }

                // 符号化
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermComp, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "M":
                            strWork = "MMR";
                            break;
                        case "R":
                            strWork = "MR";
                            break;
                        case "H":
                            strWork = "MH";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 12);
                }

                // 用紙サイズ
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermSize, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "A":
                            strWork = "A4";
                            break;
                        case "B":
                            strWork = "B4";
                            break;
                        case "3":
                            strWork = "A3";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 13);
                }

                // エラー訂正
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermECM, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "D":
                            strWork = "なし";
                            break;
                        case "E":
                            strWork = "ECM";
                            break;
                        case "S":
                            strWork = "ECM";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 14);
                }

                // 回線指定
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEMEX_LineDes, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "なし";
                            break;
                        case "0":
                            strWork = "回線１";
                            break;
                        case "1":
                            strWork = "回線２";
                            break;
                        case "2":
                            strWork = "回線３";
                            break;
                        case "3":
                            strWork = "回線４";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 15);
                }

                // 優先順位
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEMEX_Priority, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "";
                            break;
                        default:
                            break;
                    }
                    LstItems.SetValue(strWork, 16);
                }

                // リトライ回数
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Retry, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 17);
                }

                // Ｆコード番号
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FCode, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 18);
                }

                // パスワード
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Password, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 19);
                }

                // 会社名
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Company, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 20);
                }

                // 所属名
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Division, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 21);
                }

                // 役職名
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Position, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 22);
                }

                // 氏名
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Name, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 23);
                }

                // 郵便番号
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_ZipCode, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 24);
                }

                // 住所1
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Address1, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 25);
                }

                // 住所2
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Address2, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 26);
                }

                // 電話番号
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Telephone, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 27);
                }

                // FAX番号
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Fax, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 28);
                }

                // 敬称
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Title, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 29);
                }

                // ユーザ使用
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FreeArea, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 30);
                }

                // 記録位置
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_UserInfo, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 31);
                }

                // 自局電話番号
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_UserID, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 32);
                }

                // ジョブID
                if (axSFCSLogSned1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_JobID, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 33);
                }

                ListViewItem ListItem = new ListViewItem(LstItems, -1);

                ListItem.ImageIndex = iImage;

                this.ListView.Items.Add(ListItem);

            } // for (i = 0; i < axSFCSLogSned1.GetRecCount(); i++ )

            this.ListView.UseWaitCursor = false;

        }


        // ********* Here 2011/10/17 ****************


        //-------------------------------------------------------------
        // 受信ログの表示
        //-------------------------------------------------------------
        public void ViewListViewRecv()
        {

            int iImage;
            int i;
            string strTmp;

            InitLogColHeader();

            this.ListView.UseWaitCursor = true;

            //-------------------------------------------------------------
            // ステータスバー表示

            strTmp = "ログ件数:";
            strTmp += axSFCSLogRecv1.GetRecCount().ToString();
            this.ToolStripStatusLabel.Text = strTmp;

            //////////////////////////////////////////////////////////////
            /// 受信ログのリスト表示
            ///
            /// SFCSLogRecvコントロール 《 受信ログのレコード数 取得 》
            ///   Function GetRecCount() as Long
            ///

            string strWork;

            strWork = new string('\0', 1025);

            for (i = 0; i < axSFCSLogRecv1.GetRecCount(); i++ )
            {

                string[] LstItems = { "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "" };

                //////////////////////////////////////////////////////////////
                /// 各項目の取得と表示
                ///
                /// SFCSLogQueコントロール 《 未送信ログのレコード項目 文字列取得 》
                ///   Function GetRecItemString( Rec As Long, Item As Integer,
                ///                              Get As String ) as Long
                ///

                // 通信結果
                iImage = 3;
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Return, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {

                    //////////////////////////////////////////////////////////////
                    /// 通信状態取得
                    ///
                    /// SFCSLogQueコントロール 《 未送信ログのレコード 通信状態取得 》
                    ///   Function GetRecComStatus( Rec As Long,
                    ///                             GetStatus As Long ) as Long
                    ///

                    // 通信状態
                    if (strWork == "0")
                    {
                        iImage = 3;
                        LstItems.SetValue("0", 0);
                    }
                    else
                    {
                        iImage = 4;
                        LstItems.SetValue(strWork, 0);
                    }

                }

                // 日付/時刻
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Date, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 1);
                }
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Time, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 2);
                }

                // 回線番号
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Line, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 3);
                }

                // アカウント
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Acount, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 4);
                }

                // 相手先
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_SendName, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 5);
                }

                // FAX
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FaxNumber, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 6);
                }

                // ファイル名
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FileName, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 7);
                }

                // ページ数
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Page, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 8);
                }

                // 通信速度
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermSpeed, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "2":
                            strWork = "2400bps";
                            break;
                        case "4":
                            strWork = "4800bps";
                            break;
                        case "7":
                            strWork = "7200bps(V.29)";
                            break;
                        case "9":
                            strWork = "9600bps(V.29)";
                            break;
                        case "A":
                            strWork = "7200bps(V.17)";
                            break;
                        case "B":
                            strWork = "9600bps(V.17)";
                            break;
                        case "C":
                            strWork = "12000bps";
                            break;
                        case "E":
                            strWork = "14400bps";
                            break;
                        case "G":
                            strWork = "16800bps";
                            break;
                        case "H":
                            strWork = "19200bps";
                            break;
                        case "I":
                            strWork = "21600bps";
                            break;
                        case "J":
                            strWork = "24000bps";
                            break;
                        case "K":
                            strWork = "26400bps";
                            break;
                        case "L":
                            strWork = "28800bps";
                            break;
                        case "M":
                            strWork = "31200bps";
                            break;
                        case "N":
                            strWork = "33600bps";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 9);
                }

                // 通信時間
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TotalTime, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 10);
                }

                // 画品質
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermReso, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "ノーマル";
                            break;
                        case "F":
                            strWork = "ファイン";
                            break;
                        case "S":
                            strWork = "スーパーファイン";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 11);
                }

                // 符号化
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermComp, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "M":
                            strWork = "MMR";
                            break;
                        case "R":
                            strWork = "MR";
                            break;
                        case "H":
                            strWork = "MH";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 12);
                }

                // 用紙サイズ
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermSize, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "A":
                            strWork = "A4";
                            break;
                        case "B":
                            strWork = "B4";
                            break;
                        case "3":
                            strWork = "A3";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 13);
                }

                // エラー訂正
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_TermECM, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "D":
                            strWork = "なし";
                            break;
                        case "E":
                            strWork = "ECM";
                            break;
                        case "S":
                            strWork = "ECM";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 14);
                }

                // 回線指定
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEMEX_LineDes, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "なし";
                            break;
                        case "0":
                            strWork = "回線１";
                            break;
                        case "1":
                            strWork = "回線２";
                            break;
                        case "2":
                            strWork = "回線３";
                            break;
                        case "3":
                            strWork = "回線４";
                            break;
                        default:
                            strWork = "";
                            break;
                    }
                    LstItems.SetValue(strWork, 15);
                }

                // 優先順位
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEMEX_Priority, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    switch (strWork)
                    {
                        case "N":
                            strWork = "";
                            break;
                        default:
                            break;
                    }
                    LstItems.SetValue(strWork, 16);
                }

                // リトライ回数
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Retry, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 17);
                }

                // Ｆコード番号
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FCode, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 18);
                }

                // パスワード
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Password, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 19);
                }

                // 会社名
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Company, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 20);
                }

                // 所属名
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Division, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 21);
                }

                // 役職名
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Position, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 22);
                }

                // 氏名
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Name, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 23);
                }

                // 郵便番号
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_ZipCode, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 24);
                }

                // 住所1
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Address1, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 25);
                }

                // 住所2
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Address2, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 26);
                }

                // 電話番号
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Telephone, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 27);
                }

                // FAX番号
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Fax, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 28);
                }

                // 敬称
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_Title, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 29);
                }

                // ユーザ使用
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_FreeArea, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 30);
                }

                // 記録位置
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_UserInfo, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 31);
                }

                // 自局電話番号
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_UserID, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 32);
                }

                // ジョブID
                if (axSFCSLogRecv1.GetRecItemString(i, clsSFCSLogDef.SFCSLOG_ITEM_JobID, ref strWork) == clsSFCSLogDef.SFCSLOG_SUCCESS)
                {
                    LstItems.SetValue(strWork, 33);
                }

                ListViewItem ListItem = new ListViewItem(LstItems, -1);

                ListItem.ImageIndex = iImage;

                this.ListView.Items.Add(ListItem);

            } // for (i = 0; i < axSFCSLogRecv1.GetRecCount(); i++ )

            this.ListView.UseWaitCursor = false;

        }

        //*************************************************************
        // リストビュー: マウスが押された
        //*************************************************************
        private void ListView_MouseDown(object sender, MouseEventArgs e)
        {

            // 右クリックを取得
            if (e.Button == MouseButtons.Right)
            {
                s_iMouseClickMode = s_cstMouseClickMode_RightClick;
            }

        }

        //*************************************************************
        // リストビュー: マウスが離された
        //*************************************************************
        private void ListView_MouseUp(object sender, MouseEventArgs e)
        {

            // マウス状態クリア
            s_iMouseClickMode = s_cstMouseClickMode_Non;

        }

        //*************************************************************
        // リストビュー: ダブルクリック
        //*************************************************************
        private void ListView_MouseDoubleClick(object sender, MouseEventArgs e)
        {

            // ダブルクリックを取得
            System.Windows.Forms.ListViewHitTestInfo liList = null;
            System.Drawing.Point pointMouse = new System.Drawing.Point(0,0);

            pointMouse.X = e.X;
            pointMouse.Y = e.Y;
            liList = ListView.HitTest(pointMouse);

            if (liList != null)
            {

                if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
                {

                    // ログ選択モードのとき
                    if (liList.Item.Text == "未送信")
                    {
                        FocusNodePosition("未送信");
                    }
                    else if (liList.Item.Text == "送信")
                    {
                        FocusNodePosition("送信");
                    }
                    else if (liList.Item.Text == "受信")
                    {
                        FocusNodePosition("受信");
                    }
                }
                else
                {
                    mnuActionView(); // ビューア呼び出し
                }

            }

        }

        //-------------------------------------------------------------
        // ツリービューの指定ノードを選択状態に
        //-------------------------------------------------------------
        private void FocusNodePosition(string Text)
        {

            //TreeNode Node;

            foreach (TreeNode Node in GetAllNodes(TreeView.Nodes))
            {
                if (Node.Text == Text)
                {
                    TreeView.SelectedNode = Node;
                    TreeView.Focus(); //フォーカスがないと反転して表示されない。
                    break;
                }
            }

        }

        //-------------------------------------------------------------
        // ツリービューのノードを取得
        //-------------------------------------------------------------
        private System.Collections.ArrayList GetAllNodes(TreeNodeCollection Nodes)
        {

            System.Collections.ArrayList Ar = new System.Collections.ArrayList();
            //TreeNode Node;

            foreach (TreeNode Node in Nodes)
            {
                Ar.Add(Node);
                if (Node.GetNodeCount(false) > 0)
                {
                    Ar.AddRange(GetAllNodes(Node.Nodes));
                }
            }

            return Ar;

        }

        //*************************************************************
        // リストビュー: 項目クリック
        //*************************************************************
        private void ListView_Click(object sender, EventArgs e)
        {

            if (!this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
            {

                // 右クリックのメニュー表示

                if (s_iMouseClickMode == s_cstMouseClickMode_RightClick)
                {
                    ContextMenu mnuContextMenu = new ContextMenu();

                    // 位置を取得
                    POINTAPI pointMouse = new POINTAPI();
                    int lGCP;
                    int lSTC;

                    lGCP = GetCursorPos( ref pointMouse);
                    lSTC = ScreenToClient(ListView.Parent.Parent.Handle.ToInt32(), ref pointMouse);
                    MenuStrip1.ContextMenu = mnuContextMenu;
                    MenuStrip1.ContextMenu.MenuItems.Add(new System.Windows.Forms.MenuItem("ビューア （&V）", new EventHandler(this.PopViwerToolStripMenuItem_Click)));
                    MenuStrip1.ContextMenu.MenuItems.Add(new System.Windows.Forms.MenuItem("削除 （&D）", new EventHandler(this.PopDelToolStripMenuItem_Click)));

                    // ポップアップメニューの表示
                    MenuStrip1.ContextMenu.Show(this, new System.Drawing.Point(pointMouse.x, pointMouse.y));
                }

            }

        }

        //*************************************************************
        // リストビュー: ヘッダクリック
        //*************************************************************
        private void ListView_ColumnClick(object sender, ColumnClickEventArgs e)
        {

            if (!this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
            {
                // Figure out the new sorting order.
                System.Windows.Forms.SortOrder sort_order;

                if (s_bListViewSort)
                {
                    sort_order = SortOrder.Ascending;
                    s_bListViewSort = false;
                }
                else
                {
                    sort_order = SortOrder.Descending;
                    s_bListViewSort = true;
                }

                // Create a comparer.
                ListView.ListViewItemSorter = new ListViewItemComparer(e.Column, (int)sort_order);

                // Sort.
                ListView.Sort();

            }

        }

        //*************************************************************
        // ツールバー: 更新
        //*************************************************************
        private void UpdateToolStripButton_Click(object sender, EventArgs e)
        {
            mnuActionUpdate();   // 最新の情報に更新
        }

        //*************************************************************
        // ツールバー: ビューア
        //*************************************************************
        private void ViewToolStripButton_Click(object sender, EventArgs e)
        {
            mnuActionView(); // ビューア呼び出し
        }

        //*************************************************************
        // ツールバー: バージョン情報
        //*************************************************************
        private void AboutToolStripButton_Click(object sender, EventArgs e)
        {
            AboutDlg dlg = new AboutDlg();
            dlg.ShowDialog();
        }

        //*************************************************************
        // 右クリックメニュー: ビューア
        //*************************************************************
        private void PopViwerToolStripMenuItem_Click(object sender, EventArgs e)
        {
            mnuActionView(); // ビューア呼び出し
        }

        //*************************************************************
        // 右クリックメニュー: 削除
        //*************************************************************
        private void PopDelToolStripMenuItem_Click(object sender, EventArgs e)
        {
            mnuActionDelete(); // 削除処理
        }

        //*************************************************************
        // 操作メニュー: 最新の情報に更新
        //*************************************************************
        private void UpdateToolStripMenuItem_Click(object sender, EventArgs e)
        {
            mnuActionUpdate();   // 最新の情報に更新
        }

        //*************************************************************
        // 操作メニュー: FAX情報表示の終了
        //*************************************************************
        private void ExitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // このフォームを閉じます
            this.Close();
        }

        //*************************************************************
        // 編集メニュー: 削除
        //*************************************************************
        private void DelToolStripMenuItem_Click(object sender, EventArgs e)
        {
            mnuActionDelete(); // 削除処理
        }

        //*************************************************************
        // 表示メニュー: ツールバー
        //*************************************************************
        private void ToolBarToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // toolstrip の表示状態および関連メニュー項目のチェック状態を切り替えます
            ToolBarToolStripMenuItem.Checked = (!ToolBarToolStripMenuItem.Checked);
            ToolStrip.Visible = ToolBarToolStripMenuItem.Checked;
        }

        //*************************************************************
        // 表示メニュー: ステータスバー
        //*************************************************************
        private void StatusBarToolStripMenuItem_Click(object sender, EventArgs e)
        {
            // statusstrip の表示状態および関連メニュー項目のチェック状態を切り替えます
            StatusBarToolStripMenuItem.Checked = (!StatusBarToolStripMenuItem.Checked);
            StatusStrip.Visible = StatusBarToolStripMenuItem.Checked;
        }

        //*************************************************************
        // ツールメニュー: ビューア
        //*************************************************************
        private void ViewerToolStripMenuItem_Click(object sender, EventArgs e)
        {
            mnuActionView(); // ビューア呼び出し
        }

        //*************************************************************
        // ヘルプメニュー: クリック
        //*************************************************************
        private void AboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AboutDlg dlg = new AboutDlg();
            dlg.ShowDialog();
        }

        //-------------------------------------------------------------
        // ビューア呼び出し
        //-------------------------------------------------------------
        private void mnuActionView()
        {

            if (!this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
            {
                string strFilePath;
                string strViewExeName, strViewComand;
                string strViewPath;
                string strInstall;

                /////////////////////////////////////////////////////////////
                // ビューア呼び出し

                ListView.SelectedListViewItemCollection SelectedItems = this.ListView.SelectedItems;
                if (SelectedItems.Count == 0)
                {
                    return;
                }

                strInstall = new string('\0', 161);

                if (axSFCSEnv1.GetSfcsFolder(ref strInstall) == clsSFCSEnvDef.SFCSENV_SUCCESS)
                {

                    //strFilePath = SelectedItems.Item(0).SubItems(7).Text;
                    strFilePath = SelectedItems[0].SubItems[7].Text;
                    

                    strViewExeName = "\\SfCsVw.exe";
                    strViewComand = " /Tビューア ";
                    //strViewPath = Chr(34) & strInstall & strViewExeName & Chr(34) & strViewComand & Chr(34) & strFilePath & Chr(34)
                    strViewPath = "\"";
                    strViewPath += strInstall;
                    strViewPath += strViewExeName;
                    strViewPath += "\"";
                    strViewPath += strViewComand;
                    strViewPath += "\"";
                    strViewPath += strFilePath;
                    strViewPath += "\"";
                    //Shell(strViewPath, AppWinStyle.NormalFocus);
                    System.Diagnostics.Process.Start(strFilePath);
                    

                }

            }

        }

        //-------------------------------------------------------------
        // ビューアメニュー、削除メニューをDisable
        //-------------------------------------------------------------
        private void mnuActionDisable()
        {

            if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
            {
                UpdateToolStripButton.Enabled = false;
                ViewToolStripButton.Enabled = false;
                UpdateToolStripMenuItem.Enabled = false;
                DelToolStripMenuItem.Enabled = false;
                ViewerToolStripMenuItem.Enabled = false;
            }
            else
            {
                UpdateToolStripButton.Enabled = true;
                ViewToolStripButton.Enabled = true;
                UpdateToolStripMenuItem.Enabled = true;
                DelToolStripMenuItem.Enabled = true;
                ViewerToolStripMenuItem.Enabled = true;
            }

        }

        //-------------------------------------------------------------
        // 最新の情報に更新
        //-------------------------------------------------------------
        private void mnuActionUpdate()
        {
            short iVal = 0;

            if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_LOG.ToString()))
            {
                return;
            }

            if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_SEND_BEFORE.ToString()))
            {
                iVal = TREE_SELECT_TYPE_SEND_BEFORE;

                //////////////////////////////////////////////////////////////
                /// 未送信ログの再読み込み
                ///
                /// SFCSLogQueコントロール 《 未送信ログの再読み込み 》
                ///   Function Reload( Dlg As Integer ) as Long
                ///

                axSFCSLogQue1.Reload(clsSFCSLogDef.SFCSLOG_Dialog_TRUE);

            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_SEND_AFTER.ToString()))
            {
                iVal = TREE_SELECT_TYPE_SEND_AFTER;

                //////////////////////////////////////////////////////////////
                /// 送信ログの再読み込み
                ///
                /// SFCSLogSendコントロール 《 送信ログの再読み込み 》
                ///   Function Reload( Dlg As Integer ) as Long
                ///

                axSFCSLogSned1.Reload(clsSFCSLogDef.SFCSLOG_Dialog_TRUE);

            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_RECEIVE.ToString()))
            {
                iVal = TREE_SELECT_TYPE_RECEIVE;

                //////////////////////////////////////////////////////////////
                /// 受信ログの再読み込み
                ///
                /// SFCSLogSendコントロール 《 受信ログの再読み込み 》
                ///   Function Reload( Dlg As Integer ) as Long
                ///

                axSFCSLogRecv1.Reload(clsSFCSLogDef.SFCSLOG_Dialog_TRUE);

            }

            SetListView(iVal);

        }

        //-------------------------------------------------------------
        // 削除処理
        //-------------------------------------------------------------
        private void mnuActionDelete()
        {
            short iVal = 0;
            DialogResult iRet;

            if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_SEND_BEFORE.ToString()))
            {
                iVal = TREE_SELECT_TYPE_SEND_BEFORE;
            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_SEND_AFTER.ToString()))
            {
                iVal = TREE_SELECT_TYPE_SEND_AFTER;
            }
            else if (this.TreeView.SelectedNode.Tag.Equals(TREE_SELECT_TYPE_RECEIVE.ToString()))
            {
                iVal = TREE_SELECT_TYPE_RECEIVE;
            }

            switch (iVal)
            {
                case TREE_SELECT_TYPE_SEND_BEFORE:
                    iRet = MessageBox.Show("選択された 未送信情報 を削除してよろしいですか？", g_cstTITLE, MessageBoxButtons.OKCancel , MessageBoxIcon.Exclamation);
                    if (iRet == DialogResult.OK)
                    {
                        DeleteQue();
                    }
                    break;
                case TREE_SELECT_TYPE_SEND_AFTER:
                    iRet = MessageBox.Show("選択された 送信情報 を削除してよろしいですか？", g_cstTITLE, MessageBoxButtons.OKCancel, MessageBoxIcon.Exclamation);
                    if (iRet == DialogResult.OK)
                    {
                        DeleteSend();
                    }
                    break;
                case TREE_SELECT_TYPE_RECEIVE:
                    iRet = MessageBox.Show("選択された 受信情報 を削除してよろしいですか？", g_cstTITLE, MessageBoxButtons.OKCancel, MessageBoxIcon.Exclamation);
                    if (iRet == DialogResult.OK)
                    {
                        DeleteRecv();
                    }
                    break;
                default:
                    break;
            }
            
        }

        //-------------------------------------------------------------
        // 未送信情報削除命令ファイル作成
        //-------------------------------------------------------------
        private void DeleteQue()
        {

            string strDeletItem;

            if (this.ListView.Items.Count != 0)
            {

                ListView.SelectedListViewItemCollection SelectedItems = this.ListView.SelectedItems;
                //ListViewItem item;

                //////////////////////////////////////////////////////////////
                /// 削除情報の初期化
                ///
                /// SFCSLogQueコントロール 《 削除ジョブIDリスト リセット 》
                ///   Sub ResetDocInfo()
                ///

                axSFCSLogQue1.ResetDelInfo();

                foreach (ListViewItem item in SelectedItems)
                {

                    strDeletItem = item.SubItems[33].Text;

                    //////////////////////////////////////////////////////////////
                    /// 削除情報の追加
                    ///
                    /// SFCSLogQueコントロール 《 削除ジョブIDリスト 追加設定 》
                    ///   Function AddDelInfo( JobID As String ) as Long
                    ///

                    axSFCSLogQue1.AddDelInfo(strDeletItem);

                }

                //////////////////////////////////////////////////////////////
                /// 削除命令ファイル作成
                ///
                /// SFCSLogQueコントロール 《 未送信情報削除命令ファイル作成 》
                ///   Function MakeDelMission() as Long
                ///

                axSFCSLogQue1.MakeDelMission();

            }

        }

        //-------------------------------------------------------------
        // 送信情報削除命令ファイル作成
        //-------------------------------------------------------------
        private void DeleteSend()
        {

            string strDeletItem;

            if (this.ListView.Items.Count != 0)
            {

                ListView.SelectedListViewItemCollection SelectedItems = this.ListView.SelectedItems;
                //ListViewItem item;

                //////////////////////////////////////////////////////////////
                /// 削除情報の初期化
                ///
                /// SFCSLogSendコントロール 《 削除ジョブIDリスト リセット 》
                ///   Sub ResetDocInfo()
                ///

                axSFCSLogSned1.ResetDelInfo();

                foreach (ListViewItem item in SelectedItems) 
                {

                    strDeletItem = item.SubItems[33].Text;

                    //////////////////////////////////////////////////////////////
                    /// 削除情報の追加
                    ///
                    /// SFCSLogSendコントロール 《 削除ジョブIDリスト 追加設定 》
                    ///   Function AddDelInfo( JobID As String ) as Long
                    ///

                    axSFCSLogSned1.AddDelInfo(strDeletItem);

                }

                //////////////////////////////////////////////////////////////
                /// 削除命令ファイル作成
                ///
                /// SFCSLogSendコントロール 《 送信情報削除命令ファイル作成 》
                ///   Function MakeDelMission() as Long
                ///

                axSFCSLogSned1.MakeDelMission();

            }

        }

        //-------------------------------------------------------------
        // 受信情報削除命令ファイル作成
        //-------------------------------------------------------------
        private void DeleteRecv()
        {
            string strDeletItem;

            if (this.ListView.Items.Count != 0)
            {
                ListView.SelectedListViewItemCollection SelectedItems = this.ListView.SelectedItems;
                //ListViewItem item;

                //////////////////////////////////////////////////////////////
                /// 削除情報の初期化
                ///
                /// SFCSLogRecvコントロール 《 削除ジョブIDリスト リセット 》
                ///   Sub ResetDocInfo()
                ///

                axSFCSLogRecv1.ResetDelInfo();

                foreach (ListViewItem item in SelectedItems)
                {

                    strDeletItem = item.SubItems[33].Text;

                    //////////////////////////////////////////////////////////////
                    /// 削除情報の追加
                    ///
                    /// SFCSLogRecvコントロール 《 削除ジョブIDリスト 追加設定 》
                    ///   Function AddDelInfo( JobID As String ) as Long
                    ///

                    axSFCSLogRecv1.AddDelInfo(strDeletItem);

                }

                //////////////////////////////////////////////////////////////
                /// 削除命令ファイル作成
                ///
                /// SFCSLogRecvコントロール 《 受信情報削除命令ファイル作成 》
                ///   Function MakeDelMission() as Long
                ///

                axSFCSLogRecv1.MakeDelMission();

            }

        }

    }

    //-------------------------------------------------------------
    // Implements the manual sorting of items by columns.
    //-------------------------------------------------------------
    class ListViewItemComparer : System.Collections.IComparer
    {
        private int col;
        private System.Windows.Forms.SortOrder so;

        public ListViewItemComparer()
        {
            col = 0;
            so = SortOrder.Ascending;
        }

        public ListViewItemComparer(int column)
        {
            col = column;
            so = SortOrder.Ascending;
        }

        public ListViewItemComparer(int column, int sortorder)
        {
            col = column;
            so = (SortOrder)sortorder;
        }

        public int Compare(object x, object y)
        {
            //Compare(x, y);
            int ret = -1;

            if (so == SortOrder.Ascending)
            {
                //return string.Compare(CType(x, ListViewItem).SubItems(col).Text, CType(y, ListViewItem).SubItems(col).Text);
                ret =  String.Compare(((ListViewItem)x).SubItems[col].Text,
                                      ((ListViewItem)y).SubItems[col].Text);
            }
            else
            {
                //return string.Compare(CType(y, ListViewItem).SubItems(col).Text, CType(x, ListViewItem).SubItems(col).Text);
                ret = String.Compare(((ListViewItem)y).SubItems[col].Text,
                                      ((ListViewItem)x).SubItems[col].Text);
            }

            return ret;
        }

    }

}
